pyxmpp2.xmppparser

Package pyxmpp2 :: Module xmppparser |
[hide private]

# Module xmppparser

ElementTree-based XMPP stream parserg

Classes | [hide private]
| XMLStreamHandler Base class for stream handler, used as a target for XMPP parser or XMPP transports.
| ParserTarget Element tree parser events handler for the XMPP stream parser.
| StreamReader XML stream reader.

Variables | [hide private]
| COMMON_NS = ``'``http://pyxmpp.jajcus.net/xmlns/common``'``
| logger = `logging.getLogger("pyxmpp.xmppparser")`